#
# spec file for package python-ciscoconfparse
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-ciscoconfparse
Version:        1.6.0
Release:        bp156.3.2
Summary:        Library for parsing, querying and modifying Cisco IOS-style configurations
License:        GPL-3.0-or-later
URL:            https://github.com/mpenning/ciscoconfparse
Source:         https://files.pythonhosted.org/packages/source/c/ciscoconfparse/ciscoconfparse-%{version}.tar.gz
BuildRequires:  %{python_module dnspython}
BuildRequires:  %{python_module loguru}
BuildRequires:  %{python_module passlib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with python2}
BuildRequires:  python2-ipaddr >= 2.1.11
BuildRequires:  python2-mock
%endif
Requires:       python-dnspython
Requires:       python-loguru
%ifpython2
Requires:       python-ipaddr >= 2.1.11
%endif
BuildArch:      noarch
%python_subpackages

%description
ciscoconfparse is a Python library, which parses through Cisco IOS-style
(and other vendor) configurations.  It can:

- Audit existing router / switch / firewall / wlc configurations
- Retrieve portions of the configuration
- Modify existing configurations
- Build new configurations

The library examines an IOS-style config and breaks it into a set of linked
parent / child relationships.  You can perform complex queries about these
relationships.

%prep
%autosetup -p1 -n ciscoconfparse-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no online dns (and /etc/resolv.conf) available
%pytest -k "not (test_dns_lookup or test_reverse_dns_lookup)"

%files %{python_files}
%license LICENSE
%doc CHANGES README.rst
%{python_sitelib}/ciscoconfparse
%{python_sitelib}/ciscoconfparse-%{version}-py%{python_version}.egg-info

%changelog
* Tue Nov  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.60
  * Fix race-condition for `CiscoConfParse` kwarg in IOSConfigList,
    NXOSConfigList, and ASAConfigList.
  * Add explicit configuration file encoding with default encoding
    from python's locale module.
  * Add tests to catch breakage similar to Github Issue #209.
  * Remove colorama dependency.
* Tue Nov  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.51
  * New release with modified copyrights
  * Fix typos and syntax
  * Fix insert_before() and insert_after(), update Copyrights
  * Expose a proxy function to call ipaddress.collapse_addresses()
  * More logging work... prepare for debugging overhaul.
  * Refine error logging in setup.py
  * Fix get_metadata() returned value in setup.py
  * Rework version.json to metadata.json
* Tue Jul 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.36
  * Fix git tags in Makefile
  * Add a helper-function: as_text_list(); improve performance of
    .delete()
  * Fix __int__() and __index__() on IPv4Obj() and IPv6Obj()
  * Enhance ccp_util.CiscoRange() to parse a wider variety of
    string inputs
  * Remove slow code from ccp_util.CiscoRange()
  * Make ccp_util.L4Object().__repr__() more friendly
* Sat Jan 23 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.5.25
  * Fix Github Issue gh#mpenning/ciscoconfparse#195
  * merge PR gh#mpenning/ciscoconfparse#194
  * fix multiple unreported bugs in ccp_util.L4Object()
- Drop remove-mock.patch and test-lists.patch fixed upstream
* Fri Jan 22 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 1.5.24
  * Fix Github Issue #178
- Changes for 1.5.23
  * Prevent find_object_branches() from using None
- Changes for 1.5.22
  * Fix Github issue #186 (replace variables named input)
- Changes for 1.5.21
  * Fix Github issue #187
- Changes for 1.5.20
  * Fix Github issue #185
- Changes for 1.5.19
  * Add __ne__() support to IPv4Obj and IPv6Obj
- Changes for 1.5.18
  * Fix Github issue #180 - IPv4Obj() and IPv6Obj() cannot
    use logical compare ops with certain Python objects
- Changes for 1.5.17
  * Fix Python 2.7 packaging
- Changes for 1.5.7
  * Revise IPv4Obj & IPv6Obj __lt__(), __gt__(), and
    __contains__() methods (impacts sorting behavior);
    reformatted documentation to latest numpydoc format.
    Add version number as json data instead of raw text...
- Add remove-mock.patch -- gh#mpenning/ciscoconfparse#194
- Add test-lists.patch -- gh#mpenning/ciscoconfparse#195
* Sun Jun 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.6
  * Improve find_object_branches() speed
* Sat Jun 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.5
  * Beta-test new function: find_object_branches()
- Update to version 1.5.4
  * Modify IPv4Obj().__add__() and IPv6Obj().__add__() (and __sub__())
    methods return IPv4Obj()/IPv6Obj() objects.
  * Add support for int(), bin() and hex() on the IPv4Obj() and IPv6Obj()
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Sun Apr 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.3
  * Fix IPv6Obj().packed and IPv6Obj().exploded
  * add IPv4Obj().packed and IPv4Obj().exploded
- Update to version 1.5.2
  * Add __add__() and __sub__() to IPv4Obj() and IPv6Obj();
  * remove use of IPv6Obj().broadcast in IPv6Obj().__contains__()
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1
  * Remove embedded junos debugging
- Update to version 1.5.0
  * Complete rewrite of junos parser (fix Github issue #70)
  * deprecate support for Python 3.4
* Thu Dec  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.11
  * Explicitly close() open filehandles
* Mon Nov 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.10
  * Add support for parsing pathlib.Path objects which contain a
    configuration
* Fri Nov 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.9
  * Add .as_cidr_net and .as_cidr_addr on IPv4Obj and IPv6Obj
  * Merge Github PR #168; rename in_portchannel and is_portchannel
* Thu Sep 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.7:
  * various small fixes
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.5:
  * distribute tests
  * various fixes
* Thu Aug  1 2019 pgajdos@suse.com
- version update to 1.4.1
  * Fix Github issue #141; NOTE - This will break parsing helper-addresses under factory=True.  If you use this feature, please migrate your scripts to the new format
  * Implement re_search_children() directly on the CiscoConfParse() object
  * Fix Github issue #158, *KEYWORD CHANGE WARNING:* some methods formrely used a keyword called 'all_children'.  The new syntax is 'recurse' (ref: Github issue #159)
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.32:
  * No good changelog
- Remove unused patch ciscoconfparse-1.2.40-fix-tests.patch
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.30:
  * Fix bugs related to Python3 (Github issue #117)
  * Add IP helper-address parsing in models_cisco.py
  * Revert universal wheel packages (universal=0)
  * Build universal wheel packages
  * Build improvements - ref Github issue #127, #128
  * Another swing at Github issue #127
  * Rollback fix for Github issue #127
  * Attempt to fix Github issue #127
  * Fix Github issue #124-126 and Github issue #110
  * Fix Github issue #121 and Github issue #123
  * Fix Github issue #114 (Py3.5 requires different open() syntax)
  * Fix Github issue #111 (banner parsing broken in some cases)
  * Add * to MANIFEST.in
  * Attempt to resolve Github issue #106
  * Add dns_query() zone transfer as text
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Tue May 22 2018 mcepl@suse.com
- Uprgade to version 1.3.15
  * Many trivial bug fixes, see CHANGES
- Renamed skip-setuptools-hg-require.patch to
  ciscoconfparse-1.2.40-fix-tests.patch
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sun Oct  9 2016 mardnh@gmx.de
- Update to version 1.2.40
  * Fix Github issue #44 (Could not parse 'ipv6 router ospf 6').
  * Modify default value for access_vlan.
  * Add new is_portchannel property.
  * Update copyright dates.
  * Remove OSX from test matrix
- Fix source url
* Sun Mar 13 2016 dmueller@suse.com
- fix license
* Fri Feb  5 2016 tbechtold@suse.com
- Initial packaging (version 1.2.39)
